<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="zh-TW" sourcelanguage="en">
  <context>
    <name>CmdRobotAddToolShape</name>
    <message>
      <location filename="../../CommandInsertRobot.cpp" line="+215"/>
      <source>Robot</source>
      <translation>機器人</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Add tool</source>
      <translation>新增工具</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Add a tool shape to the robot</source>
      <translation>於機器人上增加工具造型</translation>
    </message>
  </context>
  <context>
    <name>CmdRobotConstraintAxle</name>
    <message>
      <location filename="../../Command.cpp" line="+158"/>
      <source>Robot</source>
      <translation>機器人</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Place robot...</source>
      <translation>放置機器人...</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Place a robot (experimental!)</source>
      <translation>放置一個機器人(測試!)</translation>
    </message>
  </context>
  <context>
    <name>CmdRobotCreateTrajectory</name>
    <message>
      <location filename="../../CommandTrajectory.cpp" line="+61"/>
      <source>Robot</source>
      <translation>機器人</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Create trajectory</source>
      <translation>建立軌跡</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Create a new empty trajectory </source>
      <translation>建立新的空軌跡</translation>
    </message>
  </context>
  <context>
    <name>CmdRobotEdge2Trac</name>
    <message>
      <location line="+257"/>
      <source>Robot</source>
      <translation>機器人</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Edge to Trajectory...</source>
      <translation>邊緣至軌跡...</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Generate a Trajectory from a set of edges</source>
      <translation>由一組邊緣產生軌跡</translation>
    </message>
  </context>
  <context>
    <name>CmdRobotExportKukaCompact</name>
    <message>
      <location filename="../../CommandExport.cpp" line="+50"/>
      <source>Robot</source>
      <translation>機器人</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Kuka compact subroutine...</source>
      <translation>Kuka精簡子程式...</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Export the trajectory as a compact KRL subroutine.</source>
      <translation>以精簡KRL子程式匯出軌跡</translation>
    </message>
  </context>
  <context>
    <name>CmdRobotExportKukaFull</name>
    <message>
      <location line="+63"/>
      <source>Robot</source>
      <translation>機器人</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Kuka full subroutine...</source>
      <translation>Kuka完整子程式...</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Export the trajectory as a full KRL subroutine.</source>
      <translation>以完整KRL子程式匯出軌跡</translation>
    </message>
  </context>
  <context>
    <name>CmdRobotInsertKukaIR125</name>
    <message>
      <location filename="../../CommandInsertRobot.cpp" line="-43"/>
      <source>Robot</source>
      <translation>機器人</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Kuka IR125</source>
      <translation>Kuka IR125</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Insert a Kuka IR125 into the document.</source>
      <translation>於此文件中插入Kula IR125</translation>
    </message>
  </context>
  <context>
    <name>CmdRobotInsertKukaIR16</name>
    <message>
      <location line="-83"/>
      <source>Robot</source>
      <translation>機器人</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Kuka IR16</source>
      <translation>Kuka IR16</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Insert a Kuka IR16 into the document.</source>
      <translation>於此文件中插入Kula IR16</translation>
    </message>
  </context>
  <context>
    <name>CmdRobotInsertKukaIR210</name>
    <message>
      <location line="+39"/>
      <source>Robot</source>
      <translation>機器人</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Kuka IR210</source>
      <translation>Kuka IR210</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Insert a Kuka IR210 into the document.</source>
      <translation>於此文件中插入Kula IR210</translation>
    </message>
  </context>
  <context>
    <name>CmdRobotInsertKukaIR500</name>
    <message>
      <location line="-85"/>
      <source>Robot</source>
      <translation>機器人</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Kuka IR500</source>
      <translation>Kuka IR500</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Insert a Kuka IR500 into the document.</source>
      <translation>於此文件中插入Kula IR500</translation>
    </message>
  </context>
  <context>
    <name>CmdRobotInsertWaypoint</name>
    <message>
      <location filename="../../CommandTrajectory.cpp" line="-228"/>
      <source>Robot</source>
      <translation>機器人</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Insert in trajectory</source>
      <translation>於軌跡中插入</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Insert robot Tool location into trajectory</source>
      <translation>插入機器人工具位置至軌跡中</translation>
    </message>
  </context>
  <context>
    <name>CmdRobotInsertWaypointPreselect</name>
    <message>
      <location line="+55"/>
      <source>Robot</source>
      <translation>機器人</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Insert in trajectory</source>
      <translation>於軌跡中插入</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Insert preselection position into trajectory (W)</source>
      <translation>插入預選位置至軌跡(W)</translation>
    </message>
  </context>
  <context>
    <name>CmdRobotRestoreHomePos</name>
    <message>
      <location filename="../../Command.cpp" line="-56"/>
      <source>Robot</source>
      <translation>機器人</translation>
    </message>
    <message>
      <location line="+1"/>
      <location line="+1"/>
      <source>Move to home</source>
      <translation>移動至原點</translation>
    </message>
  </context>
  <context>
    <name>CmdRobotSetDefaultOrientation</name>
    <message>
      <location filename="../../CommandTrajectory.cpp" line="+62"/>
      <source>Robot</source>
      <translation>機器人</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Set default orientation</source>
      <translation>設定預設方向</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>set the default orientation for subsequent commands for waypoint creation</source>
      <translation>為後續產生路標指令預設方向</translation>
    </message>
  </context>
  <context>
    <name>CmdRobotSetDefaultValues</name>
    <message>
      <location line="+37"/>
      <source>Robot</source>
      <translation>機器人</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Set default values</source>
      <translation>設定預設值</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>set the default values for speed, acceleration and continuity for subsequent commands of waypoint creation</source>
      <translation>為後續產生路標指令設定預設速度,加速度及持續性等值</translation>
    </message>
  </context>
  <context>
    <name>CmdRobotSetHomePos</name>
    <message>
      <location filename="../../Command.cpp" line="-51"/>
      <source>Robot</source>
      <translation>機器人</translation>
    </message>
    <message>
      <location line="+1"/>
      <location line="+1"/>
      <source>Set the home position</source>
      <translation>設定原點位置</translation>
    </message>
  </context>
  <context>
    <name>CmdRobotSimulate</name>
    <message>
      <location line="+142"/>
      <source>Robot</source>
      <translation>機器人</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Simulate a trajectory</source>
      <translation>模擬軌跡</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Run a simulation on a trajectory</source>
      <translation>於軌跡上進行模擬</translation>
    </message>
  </context>
  <context>
    <name>CmdRobotTrajectoryCompound</name>
    <message>
      <location filename="../../CommandTrajectory.cpp" line="+175"/>
      <source>Robot</source>
      <translation>機器人</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Trajectory compound...</source>
      <translation>軌跡物件...</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Group and connect some trajectories to one</source>
      <translation>連結並群組數個軌跡成一個</translation>
    </message>
  </context>
  <context>
    <name>CmdRobotTrajectoryDressUp</name>
    <message>
      <location line="-49"/>
      <source>Robot</source>
      <translation>機器人</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Dress up trajectory...</source>
      <translation>裝飾軌跡...</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Create a dress up object which overide som aspects of a trajectory</source>
      <translation>不考慮部份軌跡方向建立修飾物件</translation>
    </message>
  </context>
  <context>
    <name>Gui::TaskView::TaskWatcherCommands</name>
    <message>
      <location filename="../../Workbench.cpp" line="+52"/>
      <source>Trajectory tools</source>
      <translation>軌跡工具</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Robot tools</source>
      <translation>機器人設定工具</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Insert Robot</source>
      <translation>插入機器人</translation>
    </message>
  </context>
  <context>
    <name>QObject</name>
    <message>
      <location filename="../../Command.cpp" line="-126"/>
      <location line="+49"/>
      <location line="+100"/>
      <location line="+29"/>
      <location filename="../../CommandExport.cpp" line="-52"/>
      <location line="+65"/>
      <location filename="../../CommandInsertRobot.cpp" line="+181"/>
      <location filename="../../CommandTrajectory.cpp" line="-276"/>
      <location line="+56"/>
      <location line="+17"/>
      <location line="+229"/>
      <source>Wrong selection</source>
      <translation>錯誤的選取</translation>
    </message>
    <message>
      <location line="-28"/>
      <location line="+29"/>
      <location filename="../../CommandExport.cpp" line="-64"/>
      <location line="+65"/>
      <location filename="../../CommandTrajectory.cpp" line="-301"/>
      <source>Select one Robot and one Trajectory object.</source>
      <translation>選取一個機器人和一軌跡物件</translation>
    </message>
    <message>
      <location line="-24"/>
      <source>Trajectory not valid</source>
      <translation>無效軌跡</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>You need at least two way points in a trajectory to simulate.</source>
      <translation>您於軌跡需要至少兩方向點來進行模擬</translation>
    </message>
    <message>
      <location filename="../../CommandExport.cpp" line="-43"/>
      <location line="+65"/>
      <source>KRL file(*.src)</source>
      <translation>KRL file(*.src)</translation>
    </message>
    <message>
      <location line="-64"/>
      <location line="+65"/>
      <source>All Files (*.*)</source>
      <translation>所有檔 (*.*)</translation>
    </message>
    <message>
      <location line="-64"/>
      <location line="+65"/>
      <source>Export program</source>
      <translation>匯出程式</translation>
    </message>
    <message>
      <location filename="../../CommandInsertRobot.cpp" line="+1"/>
      <source>Select one robot and one shape or VRML object.</source>
      <translation>選取一個機器人和一造型或VRML物件</translation>
    </message>
    <message>
      <location filename="../../CommandTrajectory.cpp" line="+79"/>
      <source>No preselection</source>
      <translation>無預選</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>You have to hover above a geometry (Preselection) with the mouse to use this command. See documentation for details.</source>
      <translation>您需要將滑鼠停留於幾何(預選)上方來使用此功能,相系說明請查詢文件</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="-155"/>
      <source>Select one Robot to set home postion</source>
      <translation>選取一機器人設定原點位置</translation>
    </message>
    <message>
      <location line="+49"/>
      <source>Select one Robot</source>
      <translation>選取一機器人</translation>
    </message>
    <message>
      <location filename="../../CommandTrajectory.cpp" line="-24"/>
      <location line="+17"/>
      <source>Select one Trajectory object.</source>
      <translation>選取一軌跡物件</translation>
    </message>
    <message>
      <location line="+84"/>
      <source>set default speed</source>
      <translation>設定預設速度</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>speed: (e.g. 1 m/s or 3 cm/s)</source>
      <translation>速度: (e.g. 1 m/s or 3 cm/s)</translation>
    </message>
    <message>
      <location line="+9"/>
      <source>set default continuity</source>
      <translation>設定預設為連續</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>continuous ?</source>
      <translation>連續?</translation>
    </message>
    <message>
      <location line="+6"/>
      <source>set default acceleration</source>
      <translation>設定預設加速</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>acceleration: (e.g. 1 m/s^2 or 3 cm/s^2)</source>
      <translation>加速度: (e.g. 1 m/s^2 or 3 cm/s^2)</translation>
    </message>
    <message>
      <location line="+127"/>
      <source>Select the Trajectory which you want to dress up.</source>
      <translation>選擇您想裝飾之軌跡</translation>
    </message>
    <message>
      <location filename="../../Workbench.cpp" line="+26"/>
      <source>No robot files installed</source>
      <translation>無安裝之機器人檔案</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Please visit %1 and copy the files to %2</source>
      <translation>請參照%1並複製至檔案%2</translation>
    </message>
  </context>
  <context>
    <name>RobotGui::DlgTrajectorySimulate</name>
    <message>
      <location filename="../../TrajectorySimulate.ui" line="+20"/>
      <source>Simulation</source>
      <translation>模擬</translation>
    </message>
    <message>
      <location line="+38"/>
      <source>|&lt;</source>
      <translation>|&lt;</translation>
    </message>
    <message>
      <location line="+31"/>
      <source>&lt;</source>
      <translation>&lt;</translation>
    </message>
    <message>
      <location line="+31"/>
      <source>||</source>
      <translation>||</translation>
    </message>
    <message>
      <location line="+31"/>
      <source>|&gt;</source>
      <translation>|&gt;</translation>
    </message>
    <message>
      <location line="+31"/>
      <source>&gt;</source>
      <translation>&gt;</translation>
    </message>
    <message>
      <location line="+31"/>
      <source>&gt;|</source>
      <translation>&gt;|</translation>
    </message>
    <message>
      <location line="+24"/>
      <source>%</source>
      <translation>％</translation>
    </message>
    <message>
      <location line="+35"/>
      <source>Type</source>
      <translation>類型</translation>
    </message>
    <message>
      <location line="+5"/>
      <source>Name</source>
      <translation>名稱</translation>
    </message>
    <message>
      <location line="+5"/>
      <source>C</source>
      <translation>C</translation>
    </message>
    <message>
      <location line="+5"/>
      <source>V</source>
      <translation>V</translation>
    </message>
    <message>
      <location line="+5"/>
      <source>A</source>
      <translation>A</translation>
    </message>
  </context>
  <context>
    <name>RobotGui::TaskEdge2TracParameter</name>
    <message>
      <location filename="../../TaskEdge2TracParameter.cpp" line="+47"/>
      <source>TaskEdge2TracParameter</source>
      <translation>TaskEdge2TracParameter</translation>
    </message>
  </context>
  <context>
    <name>RobotGui::TaskRobot6Axis</name>
    <message>
      <location filename="../../TaskRobot6Axis.ui" line="+14"/>
      <source>Form</source>
      <translation>格式</translation>
    </message>
    <message>
      <location line="+8"/>
      <source>A1</source>
      <translation>A1</translation>
    </message>
    <message>
      <location line="+47"/>
      <source>A2</source>
      <translation>A2</translation>
    </message>
    <message>
      <location line="+47"/>
      <source>A3</source>
      <translation>A3</translation>
    </message>
    <message>
      <location line="+47"/>
      <source>A4</source>
      <translation>A4</translation>
    </message>
    <message>
      <location line="+47"/>
      <source>A5</source>
      <translation>A5</translation>
    </message>
    <message>
      <location line="+47"/>
      <source>A6</source>
      <translation>A6</translation>
    </message>
    <message>
      <location line="+57"/>
      <source>TCP: (200.23,300.23,400.23,234,343,343)</source>
      <translation>TCP: (200.23,300.23,400.23,234,343,343)</translation>
    </message>
    <message>
      <location line="+17"/>
      <source>Tool: (0,0,400,0,0,0)</source>
      <translation>工具: (0,0,400,0,0,0)</translation>
    </message>
    <message>
      <location line="+16"/>
      <source>...</source>
      <translation>...</translation>
    </message>
    <message>
      <location filename="../../TaskRobot6Axis.cpp" line="+52"/>
      <source>TaskRobot6Axis</source>
      <translation>TaskRobot6Axis</translation>
    </message>
  </context>
  <context>
    <name>RobotGui::TaskRobotControl</name>
    <message>
      <location filename="../../TaskRobotControl.cpp" line="+46"/>
      <source>TaskRobotControl</source>
      <translation>TaskRobotControl</translation>
    </message>
  </context>
  <context>
    <name>RobotGui::TaskRobotMessages</name>
    <message>
      <location filename="../../TaskRobotMessages.cpp" line="+46"/>
      <source>TaskRobotMessages</source>
      <translation>TaskRobotMessages</translation>
    </message>
  </context>
  <context>
    <name>RobotGui::TaskTrajectory</name>
    <message>
      <location filename="../../TaskTrajectory.ui" line="+20"/>
      <source>Form</source>
      <translation>格式</translation>
    </message>
    <message>
      <location line="+38"/>
      <source>|&lt;</source>
      <translation>|&lt;</translation>
    </message>
    <message>
      <location line="+31"/>
      <source>&lt;</source>
      <translation>&lt;</translation>
    </message>
    <message>
      <location line="+31"/>
      <source>||</source>
      <translation>||</translation>
    </message>
    <message>
      <location line="+31"/>
      <source>|&gt;</source>
      <translation>|&gt;</translation>
    </message>
    <message>
      <location line="+31"/>
      <source>&gt;</source>
      <translation>&gt;</translation>
    </message>
    <message>
      <location line="+31"/>
      <source>&gt;|</source>
      <translation>&gt;|</translation>
    </message>
    <message>
      <location line="+24"/>
      <source>%</source>
      <translation>％</translation>
    </message>
    <message>
      <location line="+17"/>
      <source>10 ms</source>
      <translation>10毫秒</translation>
    </message>
    <message>
      <location line="+5"/>
      <source>50 ms</source>
      <translation>50毫秒</translation>
    </message>
    <message>
      <location line="+5"/>
      <source>100 ms</source>
      <translation>100毫秒</translation>
    </message>
    <message>
      <location line="+5"/>
      <source>500 ms</source>
      <translation>500毫秒</translation>
    </message>
    <message>
      <location line="+5"/>
      <source>1 s</source>
      <translation>1秒</translation>
    </message>
    <message>
      <location line="+18"/>
      <source>Pos: (200.23, 300.23, 400.23, 234, 343 ,343)</source>
      <translation>位置: (200.23, 300.23, 400.23, 234, 343 ,343)</translation>
    </message>
    <message>
      <location line="+26"/>
      <source>Type</source>
      <translation>類型</translation>
    </message>
    <message>
      <location line="+5"/>
      <source>Name</source>
      <translation>名稱</translation>
    </message>
    <message>
      <location line="+5"/>
      <source>C</source>
      <translation>C</translation>
    </message>
    <message>
      <location line="+5"/>
      <source>V</source>
      <translation>V</translation>
    </message>
    <message>
      <location line="+5"/>
      <source>A</source>
      <translation>A</translation>
    </message>
    <message>
      <location filename="../../TaskTrajectory.cpp" line="+44"/>
      <source>Trajectory</source>
      <translation>Trajectory</translation>
    </message>
  </context>
  <context>
    <name>RobotGui::TaskTrajectoryDressUpParameter</name>
    <message>
      <location filename="../../TaskTrajectoryDressUpParameter.cpp" line="+48"/>
      <source>Dress Up Parameter</source>
      <translation>Dress Up Parameter</translation>
    </message>
  </context>
  <context>
    <name>TaskEdge2TracParameter</name>
    <message>
      <location filename="../../TaskEdge2TracParameter.ui" line="+14"/>
      <source>Form</source>
      <translation>格式</translation>
    </message>
    <message>
      <location line="+15"/>
      <source>Hide / Show</source>
      <translation>隱藏/顯示</translation>
    </message>
    <message>
      <location line="+18"/>
      <source>Edges: 0</source>
      <translation>邊緣： 0</translation>
    </message>
    <message>
      <location line="+14"/>
      <source>Cluster: 0</source>
      <translation>群組:0</translation>
    </message>
    <message>
      <location line="+11"/>
      <source>Sizing Value:</source>
      <translation>尺寸值:</translation>
    </message>
    <message>
      <location line="+31"/>
      <source>Use orientation of edge</source>
      <translation>使用邊緣之方向</translation>
    </message>
    <message>
      <source>TaskEdge2TracParameter</source>
      <translation type="obsolete">TaskEdge2TracParameter</translation>
    </message>
  </context>
  <context>
    <name>TaskRobot6Axis</name>
    <message>
      <source>TaskRobot6Axis</source>
      <translation type="obsolete">TaskRobot6Axis</translation>
    </message>
  </context>
  <context>
    <name>TaskRobotControl</name>
    <message>
      <location filename="../../TaskRobotControl.ui" line="+14"/>
      <source>Form</source>
      <translation>格式</translation>
    </message>
    <message>
      <location line="+23"/>
      <source>X+</source>
      <translation>X+</translation>
    </message>
    <message>
      <location line="+19"/>
      <source>Y+</source>
      <translation>Y+</translation>
    </message>
    <message>
      <location line="+19"/>
      <source>Z+</source>
      <translation>Z+</translation>
    </message>
    <message>
      <location line="+19"/>
      <source>A+</source>
      <translation>A+</translation>
    </message>
    <message>
      <location line="+19"/>
      <source>B+</source>
      <translation>B+</translation>
    </message>
    <message>
      <location line="+19"/>
      <source>C+</source>
      <translation>C+</translation>
    </message>
    <message>
      <location line="+19"/>
      <source>X-</source>
      <translation>X-</translation>
    </message>
    <message>
      <location line="+19"/>
      <source>Y-</source>
      <translation>Y-</translation>
    </message>
    <message>
      <location line="+19"/>
      <source>Z-</source>
      <translation>Z-</translation>
    </message>
    <message>
      <location line="+19"/>
      <source>A-</source>
      <translation>A-</translation>
    </message>
    <message>
      <location line="+19"/>
      <source>B-</source>
      <translation>B-</translation>
    </message>
    <message>
      <location line="+19"/>
      <source>C-</source>
      <translation>C-</translation>
    </message>
    <message>
      <location line="+12"/>
      <source>Tool 0</source>
      <translation>工具0</translation>
    </message>
    <message>
      <location line="+5"/>
      <source>Tool</source>
      <translation>工具</translation>
    </message>
    <message>
      <location line="+5"/>
      <source>Base 0</source>
      <translation>基礎0</translation>
    </message>
    <message>
      <location line="+5"/>
      <source>Base</source>
      <translation>基礎</translation>
    </message>
    <message>
      <location line="+5"/>
      <source>World</source>
      <translation>世界</translation>
    </message>
    <message utf8="true">
      <location line="+9"/>
      <source>50mm / 5°</source>
      <translation>50mm / 5°</translation>
    </message>
    <message utf8="true">
      <location line="+5"/>
      <source>20mm / 2°</source>
      <translation>20mm / 2°</translation>
    </message>
    <message utf8="true">
      <location line="+5"/>
      <source>10mm / 1°</source>
      <translation>10mm / 1°</translation>
    </message>
    <message utf8="true">
      <location line="+5"/>
      <source>5mm / 0.5°</source>
      <translation>5mm / 0.5°</translation>
    </message>
    <message utf8="true">
      <location line="+5"/>
      <source>1mm / 0.1°</source>
      <translation>1mm / 0.1°</translation>
    </message>
    <message>
      <source>TaskRobotControl</source>
      <translation type="obsolete">TaskRobotControl</translation>
    </message>
  </context>
  <context>
    <name>TaskRobotMessages</name>
    <message>
      <location filename="../../TaskRobotMessages.ui" line="+14"/>
      <source>Form</source>
      <translation>格式</translation>
    </message>
    <message>
      <location line="+6"/>
      <source>clear</source>
      <translation>清除</translation>
    </message>
    <message>
      <source>TaskRobotMessages</source>
      <translation type="obsolete">TaskRobotMessages</translation>
    </message>
  </context>
  <context>
    <name>TaskTrajectory</name>
    <message>
      <source>Trajectory</source>
      <translation type="obsolete">Trajectory</translation>
    </message>
  </context>
  <context>
    <name>TaskTrajectoryDressUpParameter</name>
    <message>
      <location filename="../../TaskTrajectoryDressUpParameter.ui" line="+14"/>
      <source>Form</source>
      <translation>格式</translation>
    </message>
    <message>
      <location line="+6"/>
      <source>Speed &amp; Acceleration:</source>
      <translation>速度 &amp; 加速度：</translation>
    </message>
    <message>
      <location line="+9"/>
      <source>Speed:</source>
      <translation>速度:</translation>
    </message>
    <message>
      <location line="+26"/>
      <location line="+37"/>
      <source>Use</source>
      <translation>使用</translation>
    </message>
    <message>
      <location line="-26"/>
      <source>Accel:</source>
      <translation>加速:</translation>
    </message>
    <message>
      <location line="+36"/>
      <source>Don't change Cont</source>
      <translation>不要改變內容</translation>
    </message>
    <message>
      <location line="+5"/>
      <source>Continues</source>
      <translation>繼續</translation>
    </message>
    <message>
      <location line="+5"/>
      <source>Discontinues</source>
      <translation>中止</translation>
    </message>
    <message>
      <location line="+15"/>
      <source>Position and Orientation:</source>
      <translation>位置和方向:</translation>
    </message>
    <message>
      <location line="+9"/>
      <source>(0,0,0),(0,0,0)</source>
      <translation>(0,0,0),(0,0,0)</translation>
    </message>
    <message>
      <location line="+13"/>
      <source>...</source>
      <translation>...</translation>
    </message>
    <message>
      <location line="+10"/>
      <source>Don't change Position &amp; Orientation</source>
      <translation>不要更改位置和方向</translation>
    </message>
    <message>
      <location line="+5"/>
      <source>Use Orientation</source>
      <translation>使用定向</translation>
    </message>
    <message>
      <location line="+5"/>
      <source>Add Position</source>
      <translation>增加位置</translation>
    </message>
    <message>
      <location line="+5"/>
      <source>Add Orientation</source>
      <translation>增加方向</translation>
    </message>
    <message>
      <source>Dress Up Parameter</source>
      <translation type="obsolete">Dress Up Parameter</translation>
    </message>
  </context>
  <context>
    <name>Workbench</name>
    <message>
      <location filename="../../Workbench.cpp" line="-33"/>
      <source>Robot</source>
      <translation>機器人</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Insert Robots</source>
      <translation>插入機器人</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>&amp;Robot</source>
      <translation>&amp;機器人</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Export trajectory</source>
      <translation>匯出軌跡</translation>
    </message>
  </context>
</TS>
